Payment receipt

#### Receipt: 00036 - Value: $100.00 - Date: 01/01/12

Drawee |
I/We Received from: | Client
Address: | Mainstreet 138, Cidade Araci
The importance of: | ONE HUNDRED REAIS
Referring to: | Test receivable account
Recipient |
Recipient: | Stoq Roupas e Acessórios Ltda
RG/CPF/CNPJ: | 24.198.774/7322-35
Address: | Avendia São Carlos 2333, Centro

Recipient

#### Receipt: 00036 - Value: $100.00 - Date: 01/01/12

Drawee |
I/We Received from: | Client
Address: | Mainstreet 138, Cidade Araci
The importance of: | ONE HUNDRED REAIS
Referring to: | Test receivable account
Recipient |
Recipient: | Stoq Roupas e Acessórios Ltda
RG/CPF/CNPJ: | 24.198.774/7322-35
Address: | Avendia São Carlos 2333, Centro

Recipient